<?php

/**
 * @file
 * API docs for Toastr module.
 */

/**
 * @defgroup toastr_hooks Toastr hooks
 * @{
 * Hooks that can be implemented by other modules in order to extend toastr.
 */

/**
 * Provide toasts to be displayed.
 *
 * This hook is called via a javascript callback handler that provides toastr
 * notifcatations to the current user.
 *
 * @param $account
 *   The current user account object.
 *
 * @param $timestamp
 *   The timestamp from the js polling function.
 *
 * @return
 *   An array of toastr messages to be displayed to the current user. Each toastr
 *   message is an array with the following keys:
 *   - type: The type of toastr message. Possible values are (success, info,
 *   warning, error).
 *   - message: A rendered HTML message to be used as the toastr message.
 *
 * @see hook_toastr_toast().
 */
function hook_toastr_toast($account, $timestamp) {

  $toast = array(
    'type' => 'info'
    'message' => t('A message to be displayed.'),
  );
  $toasts[] = $toast;

  $toast = array(
    'type' => 'success'
    'message' => t("@name is on a toast!", array('@name' => format_username($account)));
  );
  $toasts[] = $toast;

  return $toasts;

}

/**
 * Alter the list of toastr messages before returning them to the polling function.
 *
 * @param $toasts
 *   The list of toasts as returned by hook_toastr_toast.
 *
 * @param $account
 *   The current user account object.
 *
 * @param $timestamp
 *   The timestamp from the js polling function.
 *
 * @see hook_toastr_toast().
 */
function hook_toastr_toasts_alter(&$toasts, $account, $timestamp) {
  // Do something with the yummy toast.
  foreach ($toasts as $key => $toast) {
    // Prevent toasts from showing to anonymous users.
    if ($account->uid == 0) {
      unset($toasts[$key]);
    }
  }
}

/**
 * @}
 */
